@@ -4,6 +4,8 @@
 #include <QApplication>
 #include <QFileInfo>
 #include <QStringList>
+#include <QWebView>
+#include <QWebFrame>
 
 #ifdef Q_WS_MAEMO_5
 #   include <QtMaemo5/QMaemo5InformationBox>
@@ -131,7 +133,7 @@ MainWindow::MainWindow(QWidget *parent):
         }
         else {
             if (!library->rowCount()) {
-                library->add(":/books/2 B R 0 2 B.epub");
+                library->add(":/books/2BR02B.epub");
             }
             library->setNowReading(library->index(0));
         }
@@ -199,7 +201,7 @@ void MainWindow::showRegular()
 #else
     previousButton->setGeometry(0, geo.height() - TranslucentButton::pixels,
         TranslucentButton::pixels, TranslucentButton::pixels);
-    nextButton->setGeometry(geo.width() - TranslucentButton::pixels,
+    nextButton->setGeometry(geo.width() - TranslucentButton::pixels - 25,
         toolBar->height(), TranslucentButton::pixels, TranslucentButton::pixels);
 #endif // Q_WS_MAEMO_5
     qDebug() << "previousButton geometry" << previousButton->geometry();
@@ -218,8 +220,13 @@ void MainWindow::showBig()
     otherChildren << progress << nextButton << previousButton;
     QRect screen = QApplication::desktop()->screenGeometry();
     progress->setGeometry(0, 0, screen.width(), PROGRESS_HEIGHT);
+#if defined(Q_WS_MAEMO_5)
     nextButton->setGeometry(screen.width() - TranslucentButton::pixels, 0,
         TranslucentButton::pixels, TranslucentButton::pixels);
+#else
+    nextButton->setGeometry(screen.width() - TranslucentButton::pixels - 25, 0,
+                            TranslucentButton::pixels, TranslucentButton::pixels);
+#endif // Q_WS_MAEMO_5
     previousButton->setGeometry(0, screen.height() - TranslucentButton::pixels,
         TranslucentButton::pixels, TranslucentButton::pixels);
 
@@ -251,7 +258,8 @@ void MainWindow::showSettings()
 void MainWindow::showInfo()
 {
     if (mCurrent.isValid()) {
-        (new InfoDialog(Library::instance()->book(mCurrent), this, false))->exec();
+        (new InfoDialog(Library::instance()->book(mCurrent), this, false))->
+                exec();
     }
 }
 
@@ -407,7 +415,7 @@ void MainWindow::resizeEvent(QResizeEvent *e)
 #else
     previousButton->setGeometry(0, e->size().height() - TranslucentButton::pixels,
         TranslucentButton::pixels, TranslucentButton::pixels);
-    nextButton->setGeometry(e->size().width() - TranslucentButton::pixels,
+    nextButton->setGeometry(e->size().width() - TranslucentButton::pixels - 25,
         toolBar->height(), TranslucentButton::pixels, TranslucentButton::pixels);
 #endif // Q_WS_MAEMO_5
     qDebug() << "previousButton geometry" << previousButton->geometry();
@@ -423,12 +431,14 @@ void MainWindow::about()
     QLabel *label = new QLabel(aboutDialog);
     label->setTextFormat(Qt::RichText);
     label->setOpenExternalLinks(true);
+    label->setWordWrap(true);
     label->setText(tr("<b>Dorian %1</b><br><br>Copyright &copy; 2010 "
         "Akos Polster &lt;akos@pipacs.com&gt;<br>"
         "Licensed under GNU General Public License, Version 3<br>"
         "Source code: <a href='https://garage.maemo.org/projects/dorian/'>"
         "garage.maemo.org/projects/dorian</a>").arg(DORIAN_VERSION));
     aboutDialog->addWidget(label);
+    aboutDialog->addStretch();
     aboutDialog->show();
 }
 
