@@ -97,7 +97,8 @@ void Book::close()
 QString Book::tmpDir() const
 {
     QString tmpName = QFileInfo(mTempFile.fileName()).fileName();
-    return QDir::tempPath() + "/dorian/" + tmpName;
+    return QDir(QDir::temp().absoluteFilePath("dorian")).
+            absoluteFilePath(tmpName);
 }
 
 bool Book::extract()
@@ -112,20 +113,22 @@ bool Book::extract()
         qCritical() << "Book::extract: Failed to remove" << tmp;
         return false;
     }
-    QDir d;
-    if (!d.mkpath(tmp)) {
-        qCritical() << "Book::extract: Could not create" << tmp;
-        return false;
+    QDir d(tmp);
+    if (!d.exists()) {
+        if (!d.mkpath(tmp)) {
+            qCritical() << "Book::extract: Could not create" << tmp;
+            return false;
+        }
     }
 
     // If book comes from resource, copy it to the temporary directory first
     QString bookPath = path();
     if (bookPath.startsWith(":/books/")) {
         QFile src(bookPath);
-        QString dst(tmp + "/book.epub");
+        QString dst(QDir(tmp).absoluteFilePath("book.epub"));
         if (!src.copy(dst)) {
-            qCritical() << "Book::extract: Failed to copy built-in book to"
-                    << dst;
+            qCritical() << "Book::extract: Failed to copy built-in book"
+                    << bookPath << "to" << dst;
             return false;
         }
         bookPath = dst;
@@ -174,7 +177,7 @@ bool Book::parse()
     foreach (QString key, coverKeys) {
         if (content.contains(key)) {
             qDebug() << "Loading cover image from" << content[key].href;
-            cover = makeCover(rootPath() + "/" + content[key].href);
+            cover = makeCover(QDir(rootPath()).absoluteFilePath(content[key].href));
             break;
         }
     }
@@ -186,12 +189,14 @@ bool Book::parse()
         ncxFileName = content["ncx"].href;
     } else if (content.contains("ncxtoc")) {
         ncxFileName = content["ncxtoc"].href;
+    } else if (content.contains("toc")) {
+        ncxFileName = content["toc"].href;
     } else {
         qDebug() << "No NCX table of contents";
     }
     if (!ncxFileName.isEmpty()) {
         qDebug() << "Parsing NCX file" << ncxFileName;
-        QFile ncxFile(rootPath() + "/" + ncxFileName);
+        QFile ncxFile(QDir(rootPath()).absoluteFilePath(ncxFileName));
         source = new QXmlInputSource(&ncxFile);
         NcxHandler *ncxHandler = new NcxHandler(*this);
         errorHandler = new XmlErrorHandler();
@@ -206,7 +211,7 @@ bool Book::parse()
     // Calculate book part sizes
     size = 0;
     foreach (QString part, parts) {
-        QFileInfo info(content[part].href);
+        QFileInfo info(QDir(rootPath()).absoluteFilePath(content[part].href));
         content[part].size = info.size();
         size += content[part].size;
     }
@@ -439,27 +444,25 @@ int Book::partFromChapter(int index)
     Trace t("Book::partFromChapter");
     QString id = chapters[index];
     QString href = content[id].href;
-    QString baseRef(href);
-    QUrl url(QString("file://") + href);
-    if (url.hasFragment()) {
-        QString fragment = url.fragment();
-        baseRef.chop(fragment.length() + 1);
+    int hashPos = href.indexOf("#");
+    if (hashPos != -1) {
+        href = href.left(hashPos);
     }
+
     qDebug() << "Chapter" << index;
     qDebug() << " id" << id;
     qDebug() << " href" << href;
-    qDebug() << " base href" << baseRef;
 
     for (int i = 0; i < parts.size(); i++) {
         QString partId = parts[i];
-        if (content[partId].href == baseRef) {
-            qDebug() << "Part index for" << baseRef << "is" << i;
+        if (content[partId].href == href) {
+            qDebug() << "Part index for" << href << "is" << i;
             return i;
         }
     }
 
     qWarning() << "Book::partFromChapter: Could not find part index for"
-            << baseRef;
+            << href;
     return -1;
 }
 
